Changelog
=========

0.2.0 (2014-09-28)
------------------

- Link PyVideos in readme. [Jose Diaz-Gonzalez]

- Fix codeblock formatting. [Jose Diaz-Gonzalez]

- Merge pull request #33 from NFicano/pypi-release. [Jose Diaz-Gonzalez]

  Pypi release

- PEP8. [Jose Diaz-Gonzalez]

- Pep8. [Nick Ficano]

- Pep8. [Nick Ficano]

- Self-deprecating cleanup todos, defined encoding. [Nick Ficano]

- Explicit exception imports, removed unused method. [Nick Ficano]

- Updated readme. [Nick Ficano]

- Commented, flake8, TODOs. [Nick Ficano]

- Merge pull request #30 from josegonzalez/master. [Nick Ficano]

  Add decryption support for vevo and dashmpd. Closes #25

- Merge pull request #29 from josegonzalez/master. [Nick Ficano]

  PEP8

- Merge pull request #28 from jaimecosme/master. [Nick Ficano]

  Fix for two videos with same extension and resolution.

- Merge pull request #27 from sanfx/print_status_flush. [Nick Ficano]

  added a progress bar and percentage of download completed along with
  human readable file size

- Merge pull request #26 from sanfx/print_status_flush. [Nick Ficano]

  fixed printing  status, flushes previous status in terminal

- Merge pull request #20 from chid/patch-1. [Nick Ficano]

  Update README.md

- Merge pull request #21 from mursts/patch-py3. [Nick Ficano]

  python 3 compatibility and convert tab to space

- Merge pull request #23 from masipcat/master. [Nick Ficano]

  Now Pytube supports videos with signatures!

- Merge pull request #24 from masipcat/cipher_parser. [Nick Ficano]

  Bug fixes related with signatures and optimizations

- Merge pull request #19 from insideou7/master. [Nick Ficano]

  download uri now contains the signature by default.

- Merge pull request #16 from philipzae/patch-1. [Nick Ficano]

  fixed spelling mistake

- Added README.rst, updated copy. [NFicano]

- Merge pull request #15 from b-mcg/master. [Nick Ficano]

  Possible merge.

- Rearranged imports in cli. [NFicano]

- Part of previous commit. [NFicano]

- Renamed res arg to resolution for consistancy, moved pytube cli into
  repository root, renamed it pytubectl. [NFicano]

- Fixed malformed import. [NFicano]

- Removed unnecessary import of cli. [NFicano]

- Reorganized, rewrote setup.py using distutils. [NFicano]

- Reverted back to setuptools. cleaned up setup.py. [NFicano]

- Updated version. [NFicano]

- Changed setuptools to distutils. [NFicano]

- Renamed LICENSE.txt to LICENSE. [NFicano]

- Fixed for PyPI! [NFicano]

  * added setup.cfg * updated setup.py * renamed COPYING to LICENCE.txt.

- Merge pull request #10 from randomchars/cli. [Nick Ficano]

  Add a comman line interface

- Updated README addressing how to get the highest resolution. [NFicano]

- Merge pull request #7 from randomchars/master. [Nick Ficano]

  Video info parsing and Python 3 fixes

- Updated for Python 3.x. [NFicano]

- Added print statement back in, changed to rev 0.0.5, (1.0 will include
  unit tests, and CLI), update README. [NFicano]

- Python 3.x! Reorganized file structure, removed print statements.
  [NFicano]

- Merge pull request #4 from randomchars/master. [Nick Ficano]

  Python 3 fixes

- Merge pull request #2 from ablanco/master. [Nick Ficano]

  Fix download urls

- Pep8, pyflakes, fixed typos, better comments. [NFicano]

- Rearranged/cleaned up instructions. [NFicano]

- Updated README, added .psd to gitignore. [NFicano]

- AND a typo.. [NFicano]

- Modified installation instructions to use pip. [NFicano]

- Fixed syntax error in setup.py. [NFicano]

- Fixed classifier section of setup.py. [NFicano]

- Copy changes to README. [NFicano]

- Updated README copy. [NFicano]

- Added better exception handling, fixed a ton of bugs, added setup.py.
  [NFicano]

- Fixed typos and added bugs to README. [NFicano]

- Updated README and AUTHORS. [NFicano]

- Merge pull request #1 from lorenzogil/master. [Nick Ficano]

  Evaluate the status code and do nothing upon failure

- Bug fixes, added ability to specify output directory. [Nick Ficano]

  * added ability to specify an output directory. * added missing
  quality profiles. * handled exception when unexcepted quality profile
  returned. * videos now get sorted by quality profile.

- General housekeeping, no code modified. [Nick Ficano]

  * Added TODO * Added AUTHORS * Moved Licence agreement into COPYING.

- Removed my hardcoded path I had lazily set. [Nick Ficano]

- Renamed file sanitizing function. [Nick Ficano]

- Fixed bug causing filename to truncate word. [Nick Ficano]

  filename sanitizing function was causing the last word in the filename
  to get truncated.

- Minor project reorganizing. [Nick Ficano]

  * Moved project into subdirectory, preparing to write setup script.

- Updated readme to show off more features. [Nick Ficano]

- Cleanup, Pep8, finished docstring, 100% std lib. [Nick Ficano]

  * A bit of tidying some odds and ends. * Pep8 * Finished docstrings *
  Removed ``requests`` dependency making it compatible out of the box *
  Rewrote filename sanitization method, also fixing unicode error.

- AH! forgot a trailing quote. [Nick Ficano]

- Cleaned up the README a tad. [Nick Ficano]

- Initial commit. [Nick Ficano]


